==> haskell-wai-extra-3.1.14-34.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-extra
version:              3.1.14
visibility:           public
id:                   wai-extra-3.1.14-KCWuHky1wkt7UnW34KzUw6
key:                  wai-extra-3.1.14-KCWuHky1wkt7UnW34KzUw6
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:

    * WAI Testing Framework

    Hspec testing facilities and helpers for WAI.

    * Event Source/Event Stream

    Send server events to the client. Compatible with the JavaScript
    EventSource API.

    * Accept Override

    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).

    * Add Headers

    WAI Middleware for adding arbitrary headers to an HTTP request.

    * Clean Path

    Clean a request path to a canonical form.

    * Combine Headers

    Combine duplicate headers into one.

    * GZip Compression

    Negotiate HTTP payload gzip compression.

    * Health check endpoint

    Add an empty health check endpoint.

    * HTTP Basic Authentication

    WAI Basic Authentication Middleware which uses Authorization header.

    * JSONP

    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.

    * Method Override / Post

    Allows overriding of the HTTP request method via the _method query string
    parameter.

    * Request Logging

    Request logging middleware for development and production environments

    * Request Rewrite

    Rewrite request path info based on a custom conversion rules.

    * Select

    Dynamically choose between Middlewares.

    * Stream Files

    Convert ResponseFile type responses into ResponseStream type.

    * Virtual Host

    Redirect incoming requests to a new host based on custom rules.


    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.

category:             Web
abi:                  a2414c790ac1dbb27f82361b973bcf23
exposed:              True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.CombineHeaders
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip
    Network.Wai.Middleware.HealthCheckEndpoint
    Network.Wai.Middleware.HttpAuth Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.Local Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RealIp Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.RequestSizeLimit
    Network.Wai.Middleware.RequestSizeLimit.Internal
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.Select Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.Vhost Network.Wai.Parse Network.Wai.Request
    Network.Wai.Test Network.Wai.Test.Internal Network.Wai.UrlMap

hidden-modules:
    Network.Wai.Middleware.RequestLogger.Internal Network.Wai.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-extra-3.1.14
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-extra-3.1.14
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-extra
hs-libraries:         HSwai-extra-3.1.14-KCWuHky1wkt7UnW34KzUw6
depends:
    HUnit-1.6.2.0-8V4cpd2vyM7I9OG8MrEdHy
    aeson-2.1.2.1-1R35DvuKsJwFudsOlCM6yV
    ansi-terminal-0.11.4-6jSb6ZqnQv5806EReMBETJ base-4.16.4.0
    base64-bytestring-1.2.1.0-IHt64Gotm2vFOEZhD5akU7
    bytestring-0.11.4.0 call-stack-0.4.0-7Kj6UtaYY94JDoMxAZHX8y
    case-insensitive-1.2.1.0-2Tjf2PFkxP43DkqVUMYCmf containers-0.6.5.1
    cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp directory-1.3.6.2
    fast-logger-3.1.2-9tZgatsmlsRGbmvG0F5Cca
    http-types-0.12.4-B3znMwHTe3dL304Bd3IJgZ
    iproute-1.7.12-Fiey82fIX8U50eHtwqFDMu
    network-3.1.4.0-IeiVJWXSaeWHp5XfJw1SH3
    resourcet-1.2.6-L3rnNUXQIyNIGkCgFQVXFM
    streaming-commons-0.2.2.6-GB9r0d1CyyJLCe9Mlwe8Tn text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2 unix-2.7.2.2
    vault-0.3.1.5-KGmCdA93rcM4DaC6kTp3wh
    wai-3.2.4-JJVI15W7E9rGAtOPSLOeBU
    wai-logger-2.4.0-CfMV3BDO0qC6fxF1fwwb51
    warp-3.3.30-DAHUlH7qmMW8GtlCwsSvsK
    word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:   /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html:         /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-wai-extra-3.1.15-24-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-wai-extra.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 wai-extra
version:              3.1.15
visibility:           public
id:                   wai-extra-3.1.15-7yDJJ6J51ruIg3TJFgMx33
key:                  wai-extra-3.1.15-7yDJJ6J51ruIg3TJFgMx33
license:              MIT
maintainer:           michael@snoyman.com
author:               Michael Snoyman
stability:            Stable
homepage:             http://github.com/yesodweb/wai
synopsis:             Provides some basic WAI handlers and middleware.
description:
    Provides basic WAI handler and middleware functionality:

    * WAI Testing Framework

    Hspec testing facilities and helpers for WAI.

    * Event Source/Event Stream

    Send server events to the client. Compatible with the JavaScript
    EventSource API.

    * Accept Override

    Override the Accept header in a request. Special handling for the
    _accept query parameter (which is used throughout WAI override the
    Accept header).

    * Add Headers

    WAI Middleware for adding arbitrary headers to an HTTP request.

    * Clean Path

    Clean a request path to a canonical form.

    * Combine Headers

    Combine duplicate headers into one.

    * GZip Compression

    Negotiate HTTP payload gzip compression.

    * Health check endpoint

    Add an empty health check endpoint.

    * HTTP Basic Authentication

    WAI Basic Authentication Middleware which uses Authorization header.

    * JSONP

    \"JSON with Padding\" middleware. Automatic wrapping of JSON
    responses to convert into JSONP.

    * Method Override / Post

    Allows overriding of the HTTP request method via the _method query string
    parameter.

    * Request Logging

    Request logging middleware for development and production environments

    * Request Rewrite

    Rewrite request path info based on a custom conversion rules.

    * Select

    Dynamically choose between Middlewares.

    * Stream Files

    Convert ResponseFile type responses into ResponseStream type.

    * Virtual Host

    Redirect incoming requests to a new host based on custom rules.


    API docs and the README are available at <http://www.stackage.org/package/wai-extra>.

category:             Web
abi:                  33bef638fab80e743d3ba7a7dd359c27
exposed:              True
exposed-modules:
    Network.Wai.EventSource Network.Wai.EventSource.EventStream
    Network.Wai.Handler.CGI Network.Wai.Handler.SCGI Network.Wai.Header
    Network.Wai.Middleware.AcceptOverride
    Network.Wai.Middleware.AddHeaders Network.Wai.Middleware.Approot
    Network.Wai.Middleware.Autohead Network.Wai.Middleware.CleanPath
    Network.Wai.Middleware.CombineHeaders
    Network.Wai.Middleware.ForceDomain Network.Wai.Middleware.ForceSSL
    Network.Wai.Middleware.Gzip
    Network.Wai.Middleware.HealthCheckEndpoint
    Network.Wai.Middleware.HttpAuth Network.Wai.Middleware.Jsonp
    Network.Wai.Middleware.Local Network.Wai.Middleware.MethodOverride
    Network.Wai.Middleware.MethodOverridePost
    Network.Wai.Middleware.RealIp Network.Wai.Middleware.RequestLogger
    Network.Wai.Middleware.RequestLogger.JSON
    Network.Wai.Middleware.RequestSizeLimit
    Network.Wai.Middleware.RequestSizeLimit.Internal
    Network.Wai.Middleware.Rewrite Network.Wai.Middleware.Routed
    Network.Wai.Middleware.Select Network.Wai.Middleware.StreamFile
    Network.Wai.Middleware.StripHeaders Network.Wai.Middleware.Timeout
    Network.Wai.Middleware.ValidateHeaders Network.Wai.Middleware.Vhost
    Network.Wai.Parse Network.Wai.Request Network.Wai.Test
    Network.Wai.Test.Internal Network.Wai.UrlMap

hidden-modules:
    Network.Wai.Middleware.RequestLogger.Internal Network.Wai.Util

import-dirs:          /usr/lib/ghc-9.2.8/site-local/wai-extra-3.1.15
library-dirs:         /usr/lib/ghc-9.2.8/site-local/wai-extra-3.1.15
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-wai-extra
hs-libraries:         HSwai-extra-3.1.15-7yDJJ6J51ruIg3TJFgMx33
depends:
    HUnit-1.6.2.0-4gkKXmDNQefEQuipMNWISY
    aeson-2.1.2.1-4G6NRH3Yicj9TKX8fXoWTr
    ansi-terminal-0.11.5-FgXvUwo3mIX2g72exyhUhE base-4.16.4.0
    base64-bytestring-1.2.1.0-DECs32jOMrhU6x3ypSYAj bytestring-0.11.4.0
    call-stack-0.4.0-kYtciisYfe7TdjBJDTvHP
    case-insensitive-1.2.1.0-6AqTtfG0yj5cd4BFV01sh containers-0.6.5.1
    cookie-0.4.6-ATAyIjNvKdDFVIoN0dB8l5
    data-default-class-0.1.2.0-Kt3ErptCt5hHHi8l61h1Gp directory-1.3.6.2
    fast-logger-3.1.2-AQtkpPEy7zzKpf61wl8oWJ
    http-types-0.12.4-4jA7skhyc4O1mTcupRz8pv
    iproute-1.7.12-5Hl7VCLvmHF2LaknTOyjlO
    network-3.1.4.0-BwapeZNENJRGd3a4t7iBSJ
    resourcet-1.2.6-KSYfCEph27i1WbA0p8CCrD
    streaming-commons-0.2.2.6-BYBDcyumTobELXYn1pU9hC text-1.2.5.0
    time-1.11.1.1 transformers-0.5.6.2 unix-2.7.2.2
    vault-0.3.1.5-1WZud07yl3a9ZcipFufCGQ
    wai-3.2.4-JIqkXCnMPAzFKNQzPpgW2q
    wai-logger-2.4.1-6QyfvsheaTtLqqReEGnhrU
    warp-3.3.30-A59ReqdFC07LgOaV7Ls0Bk
    word8-0.1.3-Bbsc0ZijkBHAg5mnae6Bis

haddock-interfaces:   /usr/share/doc/haskell-wai-extra/html/wai-extra.haddock
haddock-html:         /usr/share/doc/haskell-wai-extra/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
